@@ -1,4 +1,5 @@
-from blechpy.datastructures.objects import load_experiment, load_dataset, load_project
+from blechpy.datastructures.objects import load_experiment, load_dataset
+from blechpy.datastructures.objects import load_project, load_pickled_object
 from blechpy.datastructures.dataset import dataset, port_in_dataset
 from blechpy.datastructures.experiment import experiment
 from blechpy.datastructures.project import project
